==> haskell-cryptohash-md5-0.11.101.0-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-md5
version:              0.11.101.0
visibility:           public
id:                   cryptohash-md5-0.11.101.0-6vUfYlkWPkLLhnFG6Rt237
key:                  cryptohash-md5-0.11.101.0-6vUfYlkWPkLLhnFG6Rt237
license:              BSD-3-Clause
copyright:            Vincent Hanquez, Herbert Valerio Riedel
maintainer:           Herbert Valerio Riedel <hvr@gnu.org>
homepage:             https://github.com/hvr/cryptohash-md5
synopsis:             Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.

    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.

    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.

    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.

category:             Data, Cryptography
abi:                  2173804887a70e130425e8f0284ed320
exposed:              True
exposed-modules:      Crypto.Hash.MD5
hidden-modules:       Crypto.Hash.MD5.FFI Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptohash-md5-0.11.101.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptohash-md5-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-md5
hs-libraries:         HScryptohash-md5-0.11.101.0-6vUfYlkWPkLLhnFG6Rt237
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-md5-0.11.101.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-md5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-md5
version:              0.11.101.0
visibility:           public
id:                   cryptohash-md5-0.11.101.0-4qLF99uQCgWEOQ4VorY3B5
key:                  cryptohash-md5-0.11.101.0-4qLF99uQCgWEOQ4VorY3B5
license:              BSD-3-Clause
copyright:            Vincent Hanquez, Herbert Valerio Riedel
maintainer:           Herbert Valerio Riedel <hvr@gnu.org>
homepage:             https://github.com/hvr/cryptohash-md5
synopsis:             Fast, pure and practical MD5 implementation
description:
    A practical incremental and one-pass, pure API to the
    <https://en.wikipedia.org/wiki/MD5 MD5 hash algorithm>
    (including <https://en.wikipedia.org/wiki/HMAC HMAC> support)
    with performance close to the fastest implementations available in other languages.

    The implementation is made in C with a haskell FFI wrapper that hides the C implementation.

    NOTE: This package has been forked off @cryptohash-0.11.7@ because the @cryptohash@ package
    has been deprecated and so this package continues to satisfy the need for a lightweight package
    providing the MD5 hash algorithm without any dependencies on packages other than
    @base@ and @bytestring@.

    Consequently, this package can be used as a drop-in replacement for @cryptohash@'\''s
    "Crypto.Hash.MD5" module, though with a clearly smaller footprint.

category:             Data, Cryptography
abi:                  febb572875a77b9b6d7a9bcaeb1001cd
exposed:              True
exposed-modules:      Crypto.Hash.MD5
hidden-modules:       Crypto.Hash.MD5.FFI Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptohash-md5-0.11.101.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptohash-md5-0.11.101.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-md5
hs-libraries:         HScryptohash-md5-0.11.101.0-4qLF99uQCgWEOQ4VorY3B5
depends:              base-4.16.4.0 bytestring-0.11.4.0
haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-md5/html/cryptohash-md5.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-md5/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
